@@ -23,6 +23,7 @@
 
 int  Component::m_error = 0;
 bool Component::m_selMainCo = false;
+Component* Component::m_selecComp = NULL;
 
 Component::Component( QObject* parent, QString type, QString id )
          : CompBase( parent, type, id )
@@ -38,7 +39,6 @@ Component::Component( QObject* parent, QString type, QString id )
     m_showId     = false;
     m_showVal    = false;
     m_moving     = false;
-    m_printable  = false;
     m_isMainComp = false;
     m_hidden     = false;
     m_crashed    = false;
@@ -46,6 +46,7 @@ Component::Component( QObject* parent, QString type, QString id )
     m_graphical  = false;
     m_background = "";
     m_showProperty = "";
+    m_linkNumber = -1;
 
     m_boardPos = QPointF( -1e6, -1e6 );
     m_boardRot = -1e6;
@@ -86,9 +87,10 @@ Component::Component( QObject* parent, QString type, QString id )
 new StringProp<Component>( "itemtype","","", this, &Component::itemType,  &Component::setItemType ),
 new StringProp<Component>( "CircId"  ,"","", this, &Component::getUid,    &Component::setUid ),
 new BoolProp  <Component>( "mainComp","","", this, &Component::isMainComp,&Component::setMainComp ),// Related to Subcircuit:
+new StringProp<Component>( "ShowProp","","", this, &Component::showProp,  &Component::setShowProp ),
     }} );
     addPropGroup( { "CompGraphic", {
-new StringProp<Component>( "ShowProp","","", this, &Component::showProp,  &Component::setShowProp ),
+
 new BoolProp  <Component>( "Show_id" ,"","", this, &Component::showId,    &Component::setShowId ),
 new BoolProp<Component>  ( "Show_Val","","", this, &Component::showVal,   &Component::setShowVal ),
 //new DoubProp<Component>  ( "Value"   ,"","",this, &Component::getValue,  &Component::setValue ),
@@ -127,7 +129,6 @@ bool Component::setPropStr( QString prop, QString val )
     else if( prop =="valLabelx" ) m_valLabel->m_labelx = val.toInt();   // Old: TODELETE
     else if( prop =="valLabely" ) m_valLabel->m_labely = val.toInt();   // Old: TODELETE
 
-    //else if( prop =="Show_Val" ) { setShowVal( val=="true" );}          // Old: TODELETE
     else if( prop =="Unit" )                                            // Old: TODELETE
     {
         val = val.remove(" ").replace("u","µ");
@@ -148,7 +149,6 @@ bool Component::setPropStr( QString prop, QString val )
 void Component::substitution( QString &propName ) // static
 {
     if     ( propName == "Volts"       ) propName = "Voltage";
-    //else if( propName == "Current") propName = "Value";
     else if( propName == "id"          ) propName = "label";
     else if( propName == "Duty_Square" ) propName = "Duty";
     else if( propName == "S_R_Inverted") propName = "Reset_Inverted";
@@ -175,16 +175,22 @@ void Component::mousePressEvent( QGraphicsSceneMouseEvent* event )
         event->accept();
         if( m_selMainCo )  // Used when creating Boards to set this as main component
         {
+            m_selMainCo = false;
             if( m_isMainComp ) m_isMainComp = false;
             else{
                 QList<Component*>* compList = Circuit::self()->compList();
                 for( Component* comp : *compList ) comp->m_isMainComp = false;
-                m_selMainCo  = false;
+
                 m_isMainComp = true;
             }
             update();
             return;
         }
+        else if( m_selecComp )
+        {
+            m_selecComp->compSelected( this );
+            return;
+        }
         if( event->modifiers() == Qt::ControlModifier ) setSelected( !isSelected() );
         else{
             QList<QGraphicsItem*> itemlist = Circuit::self()->selectedItems();
@@ -220,12 +226,11 @@ void Component::mouseMoveEvent( QGraphicsSceneMouseEvent* event )
     if( !(fabs( delta.x() )> 0) && !(fabs( delta.y() )> 0) ) return;
 
     QList<QGraphicsItem*> itemlist = Circuit::self()->selectedItems();
-    //if( itemlist.isEmpty() ) return;
 
     if( !m_moving ) // Get lists of elements to move and save Undo state
     {
         Circuit::self()->addCompState( NULL, "", stateNew );
-        //m_linMoveList.clear();
+
         m_conMoveList.clear();
         m_compMoveList.clear();
 
@@ -339,7 +344,7 @@ void Component::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
 
     QAction* cutAction = menu->addAction(QIcon(":/cut.svg"),tr("Cut")+"\tCtrl+X");
     connect( cutAction, &QAction::triggered,
-                   this, &Component::slotCut, Qt::UniqueConnection );
+                  this, &Component::slotCut, Qt::UniqueConnection );
 
     QAction* removeAction = menu->addAction( QIcon( ":/remove.svg"),tr("Remove")+"\tDel" );
     connect( removeAction, &QAction::triggered,
@@ -368,11 +373,11 @@ void Component::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
     
     QAction* H_flipAction = menu->addAction(QIcon(":/hflip.svg"),tr("Horizontal Flip") );
     connect( H_flipAction, &QAction::triggered,
-                     this, &Component::H_flip, Qt::UniqueConnection );
+                     this, &Component::slotH_flip, Qt::UniqueConnection );
     
     QAction* V_flipAction = menu->addAction(QIcon(":/vflip.svg"),tr("Vertical Flip") );
     connect( V_flipAction, &QAction::triggered,
-                     this, &Component::V_flip, Qt::UniqueConnection );
+                     this, &Component::slotV_flip, Qt::UniqueConnection );
 
     menu->exec(event->screenPos());
 }
@@ -444,45 +449,54 @@ void Component::slotProperties()
     m_propDialog->show();
 }
 
-void Component::H_flip()
+void Component::slotH_flip()
 {
-    Circuit::self()->addCompState( this, "hflip" );
+    if( !m_hidden ) Circuit::self()->addCompState( this, "hflip" );
     m_Hflip = -m_Hflip;
     setflip();
 }
 
-void Component::V_flip()
+void Component::slotV_flip()
 {
-    Circuit::self()->addCompState( this, "vflip" );
+    if( !m_hidden ) Circuit::self()->addCompState( this, "vflip" );
     m_Vflip = -m_Vflip;
     setflip();
 }
 
-void Component::rotateCW()
+void Component::setHflip( int hf )
 {
-    if( m_hidden ) return;
-    Circuit::self()->addCompState( this, "rotation" );
-    setRotation( rotation() + 90 );
-    //emit moved();
-    moveSignal();
+    if( hf != 1 && hf != -1 ) hf = 1;
+    m_Hflip = hf;
+    setflip();
 }
 
-void Component::rotateCCW()
+void Component::setVflip( int vf )
 {
-    if( m_hidden ) return;
-    Circuit::self()->addCompState( this, "rotation" );
-    setRotation( rotation() - 90 );
-    //emit moved();
-    moveSignal();
+    if( vf != 1 && vf != -1 ) vf = 1;
+    m_Vflip = vf;
+    setflip();
 }
 
-void Component::rotateHalf()
+void Component::setflip()
 {
-    if( m_hidden ) return;
-    Circuit::self()->addCompState( this, "rotation" );
-    setRotation( rotation() - 180);
-    //emit moved();
-    moveSignal();
+    setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
+    m_idLabel->setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
+    m_valLabel->setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
+
+    for( Pin* pin : m_signalPin ) pin->flip( m_Hflip, m_Vflip );
+
+    if( !m_hidden ) moveSignal();    // Used by sockets
+}
+
+void Component::rotateCW()   { rotateAngle( 90 ); }
+void Component::rotateCCW()  { rotateAngle( -90 ); }
+void Component::rotateHalf() { rotateAngle( -180 ); }
+
+void Component::rotateAngle( double a )
+{
+    if( !m_hidden ) Circuit::self()->addCompState( this, "rotation" );
+    Component::setRotation( rotation() + a );
+    if( !m_hidden ) moveSignal();
 }
 
 QString Component::idLabel() { return m_idLabel->toPlainText(); }
@@ -523,6 +537,7 @@ void Component::setValLabelPos( int x, int y, int rot )
 void Component::updtValLabelPos() { m_valLabel->updtLabelPos(); }
 
 void Component::setValLabelText( QString t ) { m_valLabel->setPlainText( t ); }
+QString Component::getValLabelText() { return m_valLabel->toPlainText(); }
 
 QString Component::showProp()
 {
@@ -536,33 +551,6 @@ void Component::setShowProp( QString prop )
     setShowVal( !(prop.isEmpty()) );
 }
 
-void Component::setHflip( int hf )
-{ 
-    if( ( hf != 1 ) && ( hf != -1 ) ) hf = 1;
-    m_Hflip = hf;
-    setflip();
-}
-
-void Component::setVflip( int vf )
-{ 
-    if( ( vf != 1 ) && ( vf != -1 ) ) vf = 1;
-    m_Vflip = vf; 
-    setflip();
-}
-
-void Component::setflip()
-{
-    if( m_hidden ) return;
-    setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
-    m_idLabel->setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
-    m_valLabel->setTransform( QTransform::fromScale( m_Hflip, m_Vflip ) );
-    //emit flip( m_Hflip, m_Vflip );
-    for( Pin* pin : m_signalPin ) pin->flip( m_Hflip, m_Vflip );
-
-    //emit moved();                  // Used by sockets
-    moveSignal();
-}
-
 void Component::moveSignal()
 {
     for( Pin* pin : m_signalPin ) pin->isMoved();
@@ -587,8 +575,10 @@ void Component::setHidden(bool hid, bool hidArea, bool hidLabel )
 
     if( hidLabel ){
         setShowId( false );
-        setShowProp("");
-}   }
+
+    }
+    m_valLabel->setVisible( !hidLabel ); //setShowProp("");
+}
 
 /*QString Component::print()
 {
@@ -617,7 +607,7 @@ void Component::paint( QPainter* p, const QStyleOptionGraphicsItem*, QWidget* )
 
     if( m_warning || m_crashed )
     {
-        double speed, opaci;
+        double speed=0, opaci=1;
         if( m_crashed ){
             speed = 0.1; opaci = 0;
             p->fillRect( boundingRect(), QColor(255, 100, 0, 150) );
@@ -630,10 +620,19 @@ void Component::paint( QPainter* p, const QStyleOptionGraphicsItem*, QWidget* )
         if( m_opCount > 0.6 ) m_opCount = 0.0;
         p->setOpacity( m_opCount+opaci );
     }
-    else if( m_isMainComp & !m_hidden )
+    else if( !m_hidden )
     {
-        p->fillRect( boundingRect(), Qt::yellow  );
-        p->setOpacity( 0.5 );
+        if( m_isMainComp ){
+            p->fillRect( boundingRect(), Qt::yellow  );
+            p->setOpacity( 0.5 );
+        }
+        if( m_selecComp && m_linkNumber >= 0 ){
+            p->setOpacity( 0.3 );
+            p->fillRect( boundingRect(), Qt::blue  );
+            p->setOpacity( 1 );
+            p->drawText( boundingRect(), Qt::AlignCenter, QString::number(m_linkNumber) );
+            p->setOpacity( 0.12 );
+        }
     }
     //p->drawPath( shape() );
     p->setBrush( color );
