@@ -70,9 +70,10 @@ class MAINMODULE_EXPORT Component : public CompBase, public QGraphicsItem, publi
         void updtValLabelPos();
 
         virtual void setValLabelText( QString t ) override;
+        QString getValLabelText();
 
         virtual QString showProp() override;
-        virtual void    setShowProp( QString prop )override;
+        virtual void    setShowProp( QString prop ) override;
 
         bool isGraphical() { return m_graphical; }
 
@@ -117,17 +118,23 @@ class MAINMODULE_EXPORT Component : public CompBase, public QGraphicsItem, publi
 
         void moveSignal();
 
+        void rotateAngle( double a );
+
         virtual void remove();
 
         virtual void setflip();
 
+        virtual void compSelected( Component* comp ){ m_selecComp = NULL;}
+
         void addSignalPin( Pin* pin );
         void remSignalPin( Pin* pin );
 
         virtual void paint( QPainter* painter, const QStyleOptionGraphicsItem*, QWidget* );
 
-        bool m_printable;
-
+        virtual void createLinks( QList<Component*>* l){;}
+        int m_linkNumber;
+        QString m_linkedStr;
+ static Component* m_selecComp;
     //signals:
         //void moved();
         //void flip( int h, int v );
@@ -140,8 +147,8 @@ class MAINMODULE_EXPORT Component : public CompBase, public QGraphicsItem, publi
         virtual void slotProperties();
         void rotateCCW();
         void rotateHalf();
-        void H_flip();
-        void V_flip();
+        void slotH_flip();
+        void slotV_flip();
         void slotRemove();
         void slotGroup();
         void slotCopy();
@@ -173,6 +180,7 @@ class MAINMODULE_EXPORT Component : public CompBase, public QGraphicsItem, publi
         
         int m_Hflip;
         int m_Vflip;
+
  static int m_error;
  static bool m_selMainCo;
 
