@@ -29,6 +29,9 @@ class MAINMODULE_EXPORT Hd44780 : public Hd44780_Base, public eElement
         void showPins( bool show );
 
     private:
+        void readData();
+        void readBusy();
+
         void initPuPin( int n, QString l, IoPin* pin );
         IoPin* m_pinRS;
         IoPin* m_pinRW;
