@@ -174,6 +174,8 @@ void SubCircuit::loadSubCircuit( QString fileName )
     numId = numId.split("-").last();
     Circuit* circ = Circuit::self();
 
+    QList<Component*> linkList;   // Linked  Component list
+
     QVector<QStringRef> docLines = doc.splitRef("\n");
     for( QStringRef line : docLines )
     {
@@ -301,6 +303,8 @@ void SubCircuit::loadSubCircuit( QString fileName )
                     }
                     m_compList.append( comp );
 
+                    if( !comp->m_linkedStr.isEmpty() ) linkList.append( comp );
+
                     if( type == "Tunnel" ) // Make Tunnel names unique for this subcircuit
                     {
                         Tunnel* tunnel = static_cast<Tunnel*>( comp );
@@ -309,7 +313,9 @@ void SubCircuit::loadSubCircuit( QString fileName )
                         m_subcTunnels.append( tunnel );
                 }   }
                 else qDebug() << "SubCircuit:"<<m_name<<m_id<< "ERROR Creating Component: "<<type<<uid<<label;
-}   }   }   }
+    }   }   }
+    for( Component* comp : linkList ) comp->createLinks( &m_compList );
+}
 
 Pin* SubCircuit::addPin( QString id, QString type, QString label, int pos, int xpos, int ypos, int angle, int length  )
 {
